inline bool operator==(DateTime const &left, DateTime const &right)
{
    return left.d_time == right.d_time;
}
